[![Build Status](https://travis-ci.org/rimek/radio-gtk.svg?branch=master)](https://travis-ci.org/rimek/radio-gtk)


```
python setup.py install
```

or

```
pip install rimradio
```


Run it using:
`rimradio`
